@@ -85,6 +85,7 @@ static void	usage (char *progname)
 			"   -t X       Time to keep connection.\n"
 			"              ex: -t 25  maintain connections for up to 25 seconds.\n"
 			"   -n         Do not lookup addresses, use IP numbers instead.\n"
+			"   -i         Use ident service to query the name of the fingerer\n"
 			"   -f         Do not display users' full names.\n"
 			"   -u         Ignore user-specific .efingerd file\n",
 			progname);
@@ -107,24 +108,33 @@ static void	print_version (void)
 
 
 int main (int argc, char *argv[])
-{	
+{
 	u_short i;
-	
+
 	resolve_addr = 1;
 	display_full_name = 1;
 	ignore_user = 0;
-	
+	use_ident = 0;
+
+
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
 			switch (argv[i][1]) {
 				case 't':
-					client_timeout = atoi ( argv[++i]);
+					if (++i < argc)
+						client_timeout = atoi ( argv[i]);
+					else
+						usage (argv[0]);
 					break;
 
 				case 'f':
 					display_full_name = 0;
 					break;
-                    
+
+				case 'i':
+					use_ident = 1;
+					break;
+
 				case 'v':
 					print_version ();
 					
@@ -135,31 +145,29 @@ int main (int argc, char *argv[])
 				case 'u':
 					ignore_user = 1;
 					break;
-                
+
 				case 'h':
 					usage (argv[0]);
-                	
+
 				case '-':
 
 					if (strncmp ("version", ( argv[i]+2), 7) == 0)
 						print_version ();
 
-					else if (strcmp ("help", ( argv[i]+2)) == 0)
+					else if (strncmp ("help", ( argv[i]+2), 4) == 0)
 						usage (argv[0]);
 						
 					break;
 			}
 		}
 	}
-	
-		
-	
+
 	openlog ("efingerd", LOG_PID, LOG_DAEMON);
 	alarm (client_timeout);
 	signal (SIGALRM, killtic);
-    	
+
 	inetd_service (0, 1);
-    
+
 	killsock (0);
 	killsock (1);
 	closelog ();
